document.addEventListener("DOMContentLoaded", function () {
    // 목차를 삽입할 때 인용상자(blockquote) 안에 넣고 글자체를 본명조로 변경합니다.
    const tocContainer = document.createElement('blockquote');
    tocContainer.setAttribute('data-ke-style', 'style3'); // 추가 스타일
    tocContainer.style.fontFamily = "'Noto Serif KR', serif"; // 서체를 본명조로 변경합니다.

    // 목차라는 글자를 적고 아래에 리스트를 만듭니다.(<ul id="toc">)
    tocContainer.innerHTML = '<p data-ke-size="size24"><b>목차</b></p><ul id="toc" style="list-style-type: disc; padding-left: 10px;"></ul>';

    // 목차를 삽입할 위치를 찾습니다. ID가 content-wrapper인 요소를 대상으로 함.
    const contentWrapper = document.querySelector('.tt_article_useless_p_margin.contents_style');

    // 컨테이너가 존재할 경우, 목차 인용 블럭을 삽입합니다.
    if (contentWrapper) {
        contentWrapper.insertBefore(tocContainer, contentWrapper.firstChild); // 본문 내 첫 번째 요소 앞에 삽입
    } else {
        console.warn('본문 컨테이너를 찾을 수 없습니다. 목차를 body의 첫 번째 위치에 추가합니다.');
        document.body.insertBefore(tocContainer, document.body.firstChild);
    }

    // 본문 내의 h2, h3, h4 태그를 찾아서 TOC 배열로 생성 (본문 컨테이너 내부에서만 탐색)
    const headings = contentWrapper.querySelectorAll('h2, h3, h4');

    const headingIds = {}; // 객체에 고유번호를 붙이기 위한 용도입니다.
    headings.forEach(function (heading) {
        let textContent = heading.textContent.trim(); // 제목의 내용을 양쪽 공백 제거하고 가져옵니다.

    // 제목 텍스트가 없으면 빈 문자로 처리합니다.
        if (!textContent) {
            textContent = '';
        }

    // 고유번호 생성을 위해 내용의 빈칸을 '-'로 대체하고 소문자로 변환하여 ID 생성
        let id = textContent.replace(/\s+/g, '-').toLowerCase();

    // 처음에는 1을 넣고, 동일한 내용이 존재하면 숫자를 늘려가면서 대입
        if (headingIds[id]) {
            headingIds[id] += 1;
            id = `${id}-${headingIds[id]}`;
        } else {
            headingIds[id] = 1;
        }

    // 고유 번호를 heading에 대입합니다.
        heading.id = id;

    // 리스트(<li>)와 링크(<a>)
        const listItem = document.createElement('li');
        const anchor = document.createElement('a');
        anchor.href = `#${id}`;  // 제목을 id로 불러옵니다.
        anchor.textContent = textContent; 

    // h2, h3, h4에 따라서 들여쓰기를 설정합니다.
        if (heading.tagName === 'H2') {
            listItem.style.paddingLeft = '2px';
        } else if (heading.tagName === 'H3') {
            listItem.style.paddingLeft = '10px';
        } else if (heading.tagName === 'H4') {
            listItem.style.paddingLeft = '20px';
        }

    // 서식에 특수문자를 제거합니다.
        listItem.style.listStyleType = 'none';
        listItem.appendChild(anchor);  // 링크 추가
        tocContainer.querySelector('#toc').appendChild(listItem);  // 링크에 현재 항목을 추가함
    });

    // 링크요소를 불러온다
    const tocLinks = tocContainer.querySelectorAll('a');

    //링크의 동작을 막는다
    tocLinks.forEach(link => {
        link.addEventListener('click', function (event) {
            event.preventDefault();

     // '#'을 제외한 ID 값 추출하여 해당 ID의 값을 찾음
            const targetId = this.getAttribute('href').substring(1);
            const targetElement = document.getElementById(targetId);

    // 해당 요소 위치로 스크롤 이동함
            if (targetElement) {
                window.scrollTo({
                    top: targetElement.offsetTop - 80,
                    behavior: 'smooth'
                });
            }
        });
    });
});